********
Examples
********

Introductory tutorials
======================

These are tutorial-style examples that focus on
introducing the basic principles of Nengo.

Representing values
-------------------

.. toctree::
   :maxdepth: 1

   examples/basic/single-neuron
   examples/basic/two-neurons
   examples/basic/many-neurons
   examples/basic/2d-representation
   examples/basic/combining
   examples/basic/addition

Computing functions
-------------------

.. toctree::
   :maxdepth: 1

   examples/basic/communication-channel
   examples/basic/squaring
   examples/basic/multiplication

Building dynamical systems
--------------------------

.. toctree::
   :maxdepth: 1

   examples/dynamics/integrator
   examples/dynamics/controlled-integrator
   examples/dynamics/controlled-integrator2
   examples/dynamics/oscillator
   examples/dynamics/controlled-oscillator
   examples/dynamics/lorenz-attractor

Advanced examples
=================

These examples illustrate some of the more advanced uses of Nengo.

Nodes
-----

.. toctree::
   :maxdepth: 1

   examples/usage/delay-node

Processes
---------

.. toctree::
   :maxdepth: 1

   examples/advanced/processes

Ensembles
---------

.. toctree::
   :maxdepth: 1

   examples/usage/tuning-curves
   examples/advanced/izhikevich

Connections
-----------

.. toctree::
   :maxdepth: 1

   examples/advanced/inhibitory-gating
   examples/advanced/functions-and-tuning-curves

Learning
--------

.. toctree::
   :maxdepth: 1

   examples/learning/learn-communication-channel
   examples/learning/learn-square
   examples/learning/learn-product
   examples/learning/learn-unsupervised
   examples/learning/learn-associations
   examples/learning/lmu

Networks
--------

.. toctree::
   :maxdepth: 1

   examples/networks/ensemble-array
   examples/advanced/matrix-multiplication
   examples/networks/basal-ganglia
   examples/networks/integrator-network

Under the hood
--------------

.. toctree::
   :maxdepth: 1

   examples/usage/rectified-linear
   examples/advanced/nef-summary
   examples/advanced/nef-algorithm
